# gibs-leaflet

Javascript component to integrate [NASA EOSDIS GIBS (Global Imagery Browse Services)](https://earthdata.nasa.gov/about/science-system-description/eosdis-components/global-imagery-browse-services-gibs) satellite imagery with [Leaflet](https://leafletjs.com/) maps. 


Based on [aparshin/leaflet-GIBS](https://github.com/aparshin/leaflet-GIBS), and repacked to be used as a NPM module.


Compatible with Leaflet versions > 1.x.x.

## Installation


```bash
npm install --save gibs-leaflet
```

## Usage 

```
import L from 'leaflet';
import GIBSLeaflet from 'gibs-leaflet';

const mapWithGIBSLayers = GIBSLeaflet.wrap(L);
```

### Adding layers

You can add to your Leaflet map as many GIBS layers as you wish, as follows:


* after you have defined a base layer, add it to the map
```
mapWithGIBSLayers.addLayer(baseLayer);
```

* define additional layers, one for each GIBS layer you want to be appliable to the map
```
const layer1 = new L.GIBSLayer('GMI_Snow_Rate_Asc', {
    date: new Date('2018/11/15'),
	  transparent: true
});
// more layers
```

* create an object that contains all your layers - the name you choose as the key for each layer will be the one visible on the switcher to select the corresponding layer
```
const layers = {
     'Snow rate' : layer1,
    // more layers
}
```

* create a layer control and add it to the map
```
L.control.layers(layers).addTo(mapWithGIBSLayers);

```

### Available layers

<details>
  <summary>** List of available layers **</summary>
  <p>
	  
 ``` 
Agricultural_Lands_Croplands_2000
Agricultural_Lands_Pastures_2000
AIRS_All_Sky_Outgoing_Longwave_Radiation_Daily_Day
AIRS_All_Sky_Outgoing_Longwave_Radiation_Daily_Night
AIRS_All_Sky_Outgoing_Longwave_Radiation_Monthly_Day
AIRS_All_Sky_Outgoing_Longwave_Radiation_Monthly_Night
AIRS_Carbon_Dioxide_AIRS_AMSU_Monthly
AIRS_Carbon_Dioxide_IR_Monthly
AIRS_Carbon_Monoxide_Volume_Mixing_Ratio_Daily_Day
AIRS_Carbon_Monoxide_Volume_Mixing_Ratio_Monthly_Day
AIRS_Carbon_Monoxide_Volume_Mixing_Ratio_Daily_Night
AIRS_Carbon_Monoxide_Volume_Mixing_Ratio_Monthly_Night
AIRS_Clear_Sky_Outgoing_Longwave_Radiation_Daily_Day
AIRS_Clear_Sky_Outgoing_Longwave_Radiation_Daily_Night
AIRS_Clear_Sky_Outgoing_Longwave_Radiation_Monthly_Day
AIRS_Clear_Sky_Outgoing_Longwave_Radiation_Monthly_Night
AIRS_CO_Total_Column_Day
AIRS_CO_Total_Column_Night
AIRS_Dust_Score_Ocean_Day
AIRS_Dust_Score_Ocean_Night
AIRS_Methane_Volume_Mixing_Ratio_Daily_Day
AIRS_Methane_Volume_Mixing_Ratio_Daily_Night
AIRS_Methane_Volume_Mixing_Ratio_Monthly_Day
AIRS_Methane_Volume_Mixing_Ratio_Monthly_Night
AIRS_Prata_SO2_Index_Night
AIRS_Prata_SO2_Index_Day
AIRS_Precipitation_Day
AIRS_Precipitation_Night
AIRS_RelativeHumidity_400hPa_Day
AIRS_RelativeHumidity_400hPa_Night
AIRS_RelativeHumidity_500hPa_Day
AIRS_RelativeHumidity_500hPa_Night
AIRS_RelativeHumidity_600hPa_Day
AIRS_RelativeHumidity_600hPa_Night
AIRS_RelativeHumidity_700hPa_Day
AIRS_RelativeHumidity_700hPa_Night
AIRS_RelativeHumidity_850hPa_Day
AIRS_RelativeHumidity_850hPa_Night
AIRS_Surface_Air_Temperature_Daily_Day
AIRS_Surface_Air_Temperature_Monthly_Day
AIRS_Surface_Air_Temperature_Daily_Night
AIRS_Surface_Air_Temperature_Monthly_Night
AIRS_Surface_Relative_Humidity_Daily_Day
AIRS_Surface_Relative_Humidity_Daily_Night
AIRS_Surface_Relative_Humidity_Monthly_Day
AIRS_Surface_Relative_Humidity_Monthly_Night
AIRS_Surface_Skin_Temperature_Daily_Day
AIRS_Surface_Skin_Temperature_Daily_Night
AIRS_Surface_Skin_Temperature_Monthly_Day
AIRS_Surface_Skin_Temperature_Monthly_Night
AIRS_Temperature_400hPa_Day
AIRS_Temperature_400hPa_Night
AIRS_Temperature_500hPa_Day
AIRS_Temperature_600hPa_Day
AIRS_Temperature_600hPa_Night
AIRS_Temperature_500hPa_Night
AIRS_Temperature_700hPa_Day
AIRS_Temperature_700hPa_Night
AIRS_Temperature_850hPa_Day
AIRS_Temperature_850hPa_Night
Amphibian_Richness_All_Species_2013
Amphibian_Richness_All_Threats_2013
Amphibian_Richness_Critically_Endangered_Species_2013
Amphibian_Richness_Endangered_Species_2013
Amphibian_Richness_Vulnerable_Species_2013
AMSR2_Cloud_Liquid_Water_Day
AMSR2_Cloud_Liquid_Water_Night
AMSR2_Columnar_Water_Vapor_Day
AMSR2_Columnar_Water_Vapor_Night
AMSR2_Snow_Water_Equivalent
AMSR2_Surface_Precipitation_Rate_Day
AMSR2_Surface_Precipitation_Rate_Night
AMSR2_Surface_Rain_Rate_Day
AMSR2_Surface_Rain_Rate_Night
AMSR2_Wind_Speed_Day
AMSR2_Wind_Speed_Night
AMSRE_Brightness_Temp_89H_Day
AMSRE_Brightness_Temp_89H_Night
AMSRE_Brightness_Temp_89V_Day
AMSRE_Brightness_Temp_89V_Night
AMSRE_Sea_Ice_Brightness_Temp_89H
AMSRE_Sea_Ice_Brightness_Temp_89V
AMSRE_Sea_Ice_Concentration_12km
AMSRE_Sea_Ice_Concentration_25km
AMSRE_Snow_Depth_Over_Ice
AMSRE_Surface_Precipitation_Rate_Night
AMSRE_Surface_Precipitation_Rate_Day
AMSRE_Surface_Rain_Rate_Day
AMSRE_Surface_Rain_Rate_Night
AMSRU2_Sea_Ice_Brightness_Temp_89H
AMSRU2_Sea_Ice_Brightness_Temp_89V
AMSRU2_Sea_Ice_Concentration_12km
AMSRU2_Sea_Ice_Concentration_25km
AMSRU2_Soil_Moisture_NPD_Day
AMSRU2_Soil_Moisture_NPD_Night
AMSRU2_Soil_Moisture_SCA_Day
AMSRU2_Soil_Moisture_SCA_Night
AMSUA_NOAA15_Brightness_Temp_Channel_1
AMSUA_NOAA15_Brightness_Temp_Channel_10
AMSUA_NOAA15_Brightness_Temp_Channel_11
AMSUA_NOAA15_Brightness_Temp_Channel_12
AMSUA_NOAA15_Brightness_Temp_Channel_13
AMSUA_NOAA15_Brightness_Temp_Channel_14
AMSUA_NOAA15_Brightness_Temp_Channel_15
AMSUA_NOAA15_Brightness_Temp_Channel_2
AMSUA_NOAA15_Brightness_Temp_Channel_3
AMSUA_NOAA15_Brightness_Temp_Channel_4
AMSUA_NOAA15_Brightness_Temp_Channel_5
AMSUA_NOAA15_Brightness_Temp_Channel_6
AMSUA_NOAA15_Brightness_Temp_Channel_7
AMSUA_NOAA15_Brightness_Temp_Channel_8
AMSUA_NOAA15_Brightness_Temp_Channel_9
AMSUA_NOAA16_Brightness_Temp_Channel_1
AMSUA_NOAA16_Brightness_Temp_Channel_10
AMSUA_NOAA16_Brightness_Temp_Channel_11
AMSUA_NOAA16_Brightness_Temp_Channel_12
AMSUA_NOAA16_Brightness_Temp_Channel_13
AMSUA_NOAA16_Brightness_Temp_Channel_14
AMSUA_NOAA16_Brightness_Temp_Channel_15
AMSUA_NOAA16_Brightness_Temp_Channel_2
AMSUA_NOAA16_Brightness_Temp_Channel_3
AMSUA_NOAA16_Brightness_Temp_Channel_4
AMSUA_NOAA16_Brightness_Temp_Channel_5
AMSUA_NOAA16_Brightness_Temp_Channel_6
AMSUA_NOAA16_Brightness_Temp_Channel_7
AMSUA_NOAA16_Brightness_Temp_Channel_8
AMSUA_NOAA17_Brightness_Temp_Channel_1
AMSUA_NOAA16_Brightness_Temp_Channel_9
AMSUA_NOAA17_Brightness_Temp_Channel_10
AMSUA_NOAA17_Brightness_Temp_Channel_11
AMSUA_NOAA17_Brightness_Temp_Channel_12
AMSUA_NOAA17_Brightness_Temp_Channel_13
AMSUA_NOAA17_Brightness_Temp_Channel_14
AMSUA_NOAA17_Brightness_Temp_Channel_15
AMSUA_NOAA17_Brightness_Temp_Channel_2
AMSUA_NOAA17_Brightness_Temp_Channel_3
AMSUA_NOAA17_Brightness_Temp_Channel_4
AMSUA_NOAA17_Brightness_Temp_Channel_5
AMSUA_NOAA17_Brightness_Temp_Channel_7
AMSUA_NOAA17_Brightness_Temp_Channel_6
AMSUA_NOAA17_Brightness_Temp_Channel_8
AMSUA_NOAA17_Brightness_Temp_Channel_9
Anthropogenic_Biomes_of_the_World_2001-2006
Aquarius_Sea_Surface_Salinity_L3_3Month
Aquarius_Sea_Surface_Salinity_L3_7Day_RunningMean
Aquarius_Sea_Surface_Salinity_L3_7Day_Snapshot
Aquarius_Sea_Surface_Salinity_L3_Daily
Aquarius_Sea_Surface_Salinity_L3_Monthly
Aquarius_Soil_Moisture_Daily
Aquarius_Soil_Moisture_Weekly
Aquarius_Wind_Speed_L3_7Day_Snapshot
Aquarius_Wind_Speed_L3_Daily
ASTER_GDEM_Color_Index
ASTER_GDEM_Color_Shaded_Relief
ASTER_GDEM_Greyscale_Shaded_Relief
ASTER_L1T_Radiance_Terrain_Corrected
AVISO_Absolute_Dynamic_Topography
BlueMarble_NextGeneration
BlueMarble_ShadedRelief
BlueMarble_ShadedRelief_Bathymetry
CALIPSO_Wide_Field_Camera_Radiance_v3-01
CALIPSO_Wide_Field_Camera_Radiance_v3-02
CCMP_REMSS_Meridional_Wind_Speed_Monthly
CCMP_REMSS_Scalar_Wind_Speed_Monthly
CCMP_REMSS_Zonal_Wind_Speed_Monthly
CERES_Combined_Surface_Longwave_Flux_Down_All_Sky_Monthly
CERES_Combined_Surface_Longwave_Flux_Down_Clear_Sky_Monthly
CERES_Combined_Surface_Longwave_Flux_Up_All_Sky_Monthly
CERES_Combined_Surface_Shortwave_Flux_Diffuse_All_Sky_Monthly
CERES_Combined_Surface_Longwave_Flux_Up_Clear_Sky_Monthly
CERES_Combined_Surface_Shortwave_Flux_Diffuse_Clear_Sky_Monthly
CERES_Combined_Surface_Shortwave_Flux_Direct_All_Sky_Monthly
CERES_Combined_Surface_Shortwave_Flux_Direct_Clear_Sky_Monthly
CERES_Combined_Surface_Shortwave_Flux_Down_All_Sky_Monthly
CERES_Combined_Surface_Shortwave_Flux_Down_Clear_Sky_Monthly
CERES_Combined_Surface_Shortwave_Flux_Up_All_Sky_Monthly
CERES_Combined_Surface_Shortwave_Flux_Up_Clear_Sky_Monthly
CERES_Combined_Surface_UV_Index_All_Sky_Monthly
CERES_Combined_Surface_Window_Region_Flux_Down_All_Sky_Monthly
CERES_Combined_Surface_Window_Region_Flux_Down_Clear_Sky_Monthly
CERES_Combined_Surface_Window_Region_Flux_Up_All_Sky_Monthly
CERES_Combined_Surface_Window_Region_Flux_Up_Clear_Sky_Monthly
CERES_Combined_TOA_Shortwave_Flux_Clear_Sky_Monthly
CERES_Combined_TOA_Window_Region_Flux_All_Sky_Monthly
CERES_Combined_TOA_Window_Region_Flux_Clear_Sky_Monthly
CERES_EBAF_Surface_CRE_Net_Longwave_Flux_Monthly
CERES_EBAF_Surface_CRE_Net_Shortwave_Flux_Monthly
CERES_EBAF_Surface_CRE_Net_Total_Flux_Monthly
CERES_EBAF_Surface_Longwave_Flux_Down_All_Sky_Monthly
CERES_EBAF_Surface_Longwave_Flux_Down_Clear_Sky_Monthly
CERES_EBAF_Surface_Longwave_Flux_Up_All_Sky_Monthly
CERES_EBAF_Surface_Longwave_Flux_Up_Clear_Sky_Monthly
CERES_Combined_TOA_Shortwave_Flux_All_Sky_Monthly
CERES_Combined_TOA_Longwave_Flux_Clear_Sky_Monthly
CERES_EBAF_Surface_Net_Longwave_Flux_All_Sky_Monthly
CERES_EBAF_Surface_Net_Shortwave_Flux_Clear_Sky_Monthly
CERES_EBAF_Surface_Net_Longwave_Flux_Clear_Sky_Monthly
CERES_EBAF_Surface_Net_Shortwave_Flux_All_Sky_Monthly
CERES_EBAF_Surface_Net_Total_Flux_All_Sky_Monthly
CERES_EBAF_Surface_Shortwave_Flux_Down_All_Sky_Monthly
CERES_EBAF_Surface_Net_Total_Flux_Clear_Sky_Monthly
CERES_EBAF_Surface_Shortwave_Flux_Down_Clear_Sky_Monthly
CERES_EBAF_Surface_Shortwave_Flux_Up_All_Sky_Monthly
CERES_EBAF_Surface_Shortwave_Flux_Up_Clear_Sky_Monthly
CERES_EBAF_TOA_CRE_Longwave_Flux_Monthly
CERES_EBAF_TOA_CRE_Shortwave_Flux_Monthly
CERES_EBAF_TOA_CRE_Net_Flux_Monthly
CERES_EBAF_TOA_Incoming_Solar_Flux_Monthly
CERES_EBAF_TOA_Longwave_Flux_All_Sky_Monthly
CERES_EBAF_TOA_Longwave_Flux_Clear_Sky_Monthly
CERES_EBAF_TOA_Net_Flux_All_Sky_Monthly
CERES_EBAF_TOA_Net_Flux_Clear_Sky_Monthly
CERES_EBAF_TOA_Shortwave_Flux_All_Sky_Monthly
CERES_Terra_Surface_Longwave_Flux_Down_All_Sky_Monthly
CERES_EBAF_TOA_Shortwave_Flux_Clear_Sky_Monthly
CERES_Terra_Surface_Longwave_Flux_Up_Clear_Sky_Monthly
CERES_Terra_Surface_Longwave_Flux_Up_All_Sky_Monthly
CERES_Terra_Surface_Longwave_Flux_Down_Clear_Sky_Monthly
CERES_Terra_Surface_Shortwave_Flux_Diffuse_All_Sky_Monthly
CERES_Terra_Surface_Shortwave_Flux_Diffuse_Clear_Sky_Monthly
CERES_Terra_Surface_Shortwave_Flux_Direct_Clear_Sky_Monthly
CERES_Terra_Surface_Shortwave_Flux_Direct_All_Sky_Monthly
CERES_Terra_Surface_Shortwave_Flux_Down_All_Sky_Monthly
CERES_Terra_Surface_Shortwave_Flux_Down_Clear_Sky_Monthly
CERES_Terra_Surface_Shortwave_Flux_Up_All_Sky_Monthly
CERES_Terra_Surface_Shortwave_Flux_Up_Clear_Sky_Monthly
CERES_Terra_Surface_UV_Index_All_Sky_Monthly
CERES_Terra_Surface_Window_Region_Flux_Down_All_Sky_Monthly
CERES_Terra_Surface_Window_Region_Flux_Down_Clear_Sky_Monthly
CERES_Terra_Surface_Window_Region_Flux_Up_All_Sky_Monthly
CERES_Terra_Surface_Window_Region_Flux_Up_Clear_Sky_Monthly
CERES_Terra_TOA_Longwave_Flux_All_Sky_Monthly
CERES_Terra_TOA_Shortwave_Flux_All_Sky_Monthly
CERES_Terra_TOA_Longwave_Flux_Clear_Sky_Monthly
CERES_Terra_TOA_Shortwave_Flux_Clear_Sky_Monthly
CERES_Terra_TOA_Window_Region_Flux_All_Sky_Monthly
CERES_Terra_TOA_Window_Region_Flux_Clear_Sky_Monthly
Coastlines
Daymet_Maximum_Air_Temp_Daily
CYGNSS_L3_Wind_Speed_Daily
Daymet_Minimum_Air_Temp_Daily
Estimated_Net_Migration_1970-1980
Estimated_Net_Migration_1980-1990
Estimated_Net_Migration_1990-2000
GHRSST_L4_AVHRR-OI_Sea_Surface_Temperature
GHRSST_L4_G1SST_Sea_Surface_Temperature
GLDAS_Near_Surface_Air_Temperature_Monthly
GHRSST_L4_MUR_Sea_Surface_Temperature
GLDAS_Surface_Total_Precipitation_Rate_Monthly
GLDAS_Underground_Soil_Moisture_Monthly
GMI_Brightness_Temp_Asc
GMI_Brightness_Temp_Dsc
GMI_Rain_Rate_Asc
GMI_Rain_Rate_Dsc
GMI_Snow_Rate_Asc
GMI_Snow_Rate_Dsc
GPW_Population_Density_2000
GPW_Population_Density_2005
GPW_Population_Density_2010
GPW_Population_Density_2015
GPW_Population_Density_2020
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Land_GFZ
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Land_CSR
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Land_JPL
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Mascon
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Mascon_CRI
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Ocean_CSR
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Ocean_EOF_CSR
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Ocean_EOF_GFZ
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Ocean_EOF_JPL
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Ocean_GFZ
GRACE_Tellus_Liquid_Water_Equivalent_Thickness_Ocean_JPL
Ground_Level_Nitrogen_Dioxide_3_Year_Running_Mean_1996-1998
Ground_Level_Nitrogen_Dioxide_3_Year_Running_Mean_2010-2012
GRUMP_Urban_Extents_Grid_1995
Human_Footprint_1995-2004
IMERG_Rain_Rate
IMERG_Snow_Rate
Landsat_Global_Man-made_Impervious_Surface
Landsat_WELD_CONUS_5_Year_Tree_Cover
Landsat_Human_Built-up_And_Settlement_Extent
Landsat_WELD_CorrectedReflectance_TrueColor_Alaska_Annual
Landsat_WELD_CorrectedReflectance_TrueColor_Alaska_Seasonal
Landsat_WELD_CorrectedReflectance_TrueColor_Alaska_Monthly
Landsat_WELD_CorrectedReflectance_TrueColor_CONUS_Annual
Landsat_WELD_CorrectedReflectance_TrueColor_CONUS_Seasonal
Landsat_WELD_CorrectedReflectance_TrueColor_CONUS_Monthly
Landsat_WELD_CorrectedReflectance_TrueColor_Global_Annual
Landsat_WELD_CorrectedReflectance_TrueColor_Global_Monthly
Landsat_WELD_NDVI_Global_Annual
Landsat_WELD_NDVI_Global_Monthly
Last_of_the_Wild_1995-2004
LECZ_Urban_Rural_Extents_Below_10m
LIS_High_Resolution_Full_Climatology_Combined_Flash_Rate_Climatology
LIS_High_Resolution_Full_Climatology_LIS_Flash_Rate_Climatology
LIS_High_Resolution_Full_Climatology_LIS_Scaled_Flashes
LIS_High_Resolution_Full_Climatology_LIS_Raw_Flashes
LIS_ISS_Flash_Count
LIS_ISS_Flash_Radiance
LIS_TRMM_Flash_Radiance
LIS_Very_High_Resolution_Lightning_Daily_Climatology_LIS_Mean_Flash_Rate
LIS_Very_High_Resolution_Lightning_Full_Climatology_LIS_Mean_Flash_Rate
LIS_Very_High_Resolution_Lightning_Monthly_Climatology_LIS_Mean_Flash_Rate
LIS_Very_High_Resolution_Lightning_Seasonal_Climatology_LIS_Mean_Flash_Rate
LPRM_AMSR2_Downscaled_Surface_Soil_Moisture_C1_Band_Day_Daily
LPRM_AMSR2_Downscaled_Surface_Soil_Moisture_C1_Band_Night_Daily
LPRM_AMSR2_Surface_Soil_Moisture_C1_Band_Day_Daily
LPRM_AMSR2_Surface_Soil_Moisture_C1_Band_Night_Daily
LPRM_AMSRE_Surface_Soil_Moisture_C_Band_Day_Daily
LPRM_AMSRE_Surface_Soil_Moisture_C_Band_Night_Daily
LPRM_TMI_Surface_Soil_Moisture_X_Band_Day_Daily
Mammal_Richness_Grids_All_Species_2013
LPRM_TMI_Surface_Soil_Moisture_X_Band_Night_Daily
Mammal_Richness_Grids_All_Threats_2013
Mammal_Richness_Grids_Endangered_Species_2013
Mammal_Richness_Grids_Critically_Endangered_Species_2013
Mammal_Richness_Grids_Vulnerable_Species_2013
Mangrove_Forest_Distribution_2000
MEaSUREs_Daily_Landscape_Freeze_Thaw_AMSRE
MEaSUREs_Daily_Landscape_Freeze_Thaw_SSMI
MERRA2_2m_Air_Temperature_Assimilated_Monthly
MERRA2_2m_Air_Temperature_Monthly
MERRA2_Aerosol_Optical_Depth_Analysis_Monthly
MERRA2_Air_Temperature_250hPa_Monthly
MERRA2_Carbon_Monoxide_Emission_Monthly
MERRA2_Convective_Rainwater_Source_700hPa_Monthly
MERRA2_Dust_Surface_Mass_Concentration_Monthly
MERRA2_Dust_Surface_Mass_Concentration_PM25_Monthly
MERRA2_Evaporation_from_Turbulence_Monthly
MERRA2_Evaporation_Land_Monthly
MERRA2_Incident_Shortwave_Over_Land_Monthly
MERRA2_ISCCP_Cloud_Albedo_Monthly
MERRA2_Ozone_Mixing_Ratio_50hPa_Monthly
MERRA2_Open_Water_Latent_Energy_Flux_Monthly
MERRA2_Precipitation_Bias_Corrected_Monthly
MERRA2_Relative_Humidity_After_Moist_700hPa_Monthly
MERRA2_Snowfall_Monthly
MERRA2_Snow_Depth_Over_Glaciated_Surface_Monthly
MERRA2_SO2_Column_Mass_Density_Monthly
MERRA2_Surface_Albedo_Monthly
MERRA2_Soil_Water_Root_Zone_Monthly
MERRA2_Surface_Pressure_Monthly
MERRA2_Surface_Skin_Temperature_Monthly
MERRA2_Surface_Wind_Speed_Monthly
MERRA2_Total_Aerosol_Optical_Thickness_550nm_Extinction_Monthly
MERRA2_Total_Aerosol_Optical_Thickness_550nm_Scattering_Monthly
MERRA2_Total_Dust_Deposition_Dry_Wet_Monthly
MERRA2_Total_Precipitable_Water_Vapor_Monthly
MERRA_Surface_Pressure_Monthly
MERRA_Surface_Skin_Temperature_Monthly
MISR_Aerosol_Optical_Depth_Avg_Green_Monthly
MISR_AM1_Ellipsoid_Radiance_NGB_AA
MISR_AM1_Ellipsoid_Radiance_NGB_AF
MISR_AM1_Ellipsoid_Radiance_NGB_AN
MISR_AM1_Ellipsoid_Radiance_NGB_BA
MISR_AM1_Ellipsoid_Radiance_NGB_BF
MISR_AM1_Ellipsoid_Radiance_NGB_CA
MISR_AM1_Ellipsoid_Radiance_NGB_DA
MISR_AM1_Ellipsoid_Radiance_NGB_CF
MISR_AM1_Ellipsoid_Radiance_NGB_DF
MISR_AM1_Ellipsoid_Radiance_RGB_AA
MISR_AM1_Ellipsoid_Radiance_RGB_AF
MISR_AM1_Ellipsoid_Radiance_RGB_AN
MISR_AM1_Ellipsoid_Radiance_RGB_BA
MISR_AM1_Ellipsoid_Radiance_RGB_BF
MISR_AM1_Ellipsoid_Radiance_RGB_CA
MISR_AM1_Ellipsoid_Radiance_RGB_CF
MISR_AM1_Ellipsoid_Radiance_RGB_DA
MISR_AM1_Ellipsoid_Radiance_RGB_DF
MISR_Cloud_Stereo_Height_Histogram_Bin_0.5km_Monthly
MISR_Cloud_Stereo_Height_Histogram_Bin_1.5-2.0km_Monthly
MISR_Directional_Hemispherical_Reflectance_Average_Natural_Color_Monthly
MISR_Radiance_Average_Infrared_Color_Monthly
MISR_Land_NDVI_Average_Monthly
MISR_Radiance_Average_Natural_Color_Monthly
MLS_CO_215hPa_Day
MISR_TOA_Albedo_Average_Red_Monthly
MLS_CO_215hPa_Night
MLS_H2O_46hPa_Day
MLS_HNO3_46hPa_Day
MLS_H2O_46hPa_Night
MLS_HNO3_46hPa_Night
MLS_N2O_46hPa_Day
MLS_N2O_46hPa_Night
MLS_O3_46hPa_Day
MLS_O3_46hPa_Night
MLS_SO2_147hPa_Day
MLS_SO2_147hPa_Night
MLS_Temperature_46hPa_Day
MLS_Temperature_46hPa_Night
MODIS_Aqua_Aerosol_Optical_Depth_3km
MODIS_Aqua_Aerosol
MODIS_Aqua_Angstrom_Exponent_Land
MODIS_Aqua_AOD_Deep_Blue_Combined
MODIS_Aqua_Angstrom_Exponent_Ocean
MODIS_Aqua_AOD_Deep_Blue_Land
MODIS_Aqua_Brightness_Temp_Band31_Day
MODIS_Aqua_Brightness_Temp_Band31_Night
MODIS_Aqua_Chlorophyll_A
MODIS_Aqua_Cloud_Effective_Radius
MODIS_Aqua_Cloud_Effective_Radius_37_PCL
MODIS_Aqua_Cloud_Effective_Radius_37
MODIS_Aqua_Cloud_Effective_Radius_PCL
MODIS_Aqua_Cloud_Fraction_Day
MODIS_Aqua_Cloud_Fraction_Night
MODIS_Aqua_Cloud_Multi_Layer_Flag
MODIS_Aqua_Cloud_Optical_Thickness
MODIS_Aqua_Cloud_Optical_Thickness_PCL
MODIS_Aqua_Cloud_Phase_Infrared_Day
MODIS_Aqua_Cloud_Phase_Infrared_Night
MODIS_Aqua_Cloud_Phase_Optical_Properties
MODIS_Aqua_Cloud_Top_Height_Day
MODIS_Aqua_Cloud_Top_Pressure_Day
MODIS_Aqua_Cloud_Top_Height_Night
MODIS_Aqua_Cloud_Top_Pressure_Night
MODIS_Aqua_Cloud_Top_Temp_Day
MODIS_Aqua_Cloud_Top_Temp_Night
MODIS_Aqua_Cloud_Water_Path
MODIS_Aqua_Cloud_Water_Path_PCL
MODIS_Aqua_CorrectedReflectance_Bands721
MODIS_Aqua_CorrectedReflectance_TrueColor
MODIS_Aqua_Data_No_Data
MODIS_Aqua_Ice_Surface_Temp_Day
MODIS_Aqua_Ice_Surface_Temp_Night
MODIS_Aqua_L3_SST_MidIR_4km_Night_8Day
MODIS_Aqua_L3_SST_MidIR_4km_Night_Annual
MODIS_Aqua_L3_SST_MidIR_4km_Night_Monthly
MODIS_Aqua_L3_SST_MidIR_4km_Night_Daily
MODIS_Aqua_L3_SST_MidIR_9km_Night_8Day
MODIS_Aqua_L3_SST_MidIR_9km_Night_Annual
MODIS_Aqua_L3_SST_MidIR_9km_Night_Daily
MODIS_Aqua_L3_SST_MidIR_9km_Night_Monthly
MODIS_Aqua_L3_SST_Thermal_4km_Day_8Day
MODIS_Aqua_L3_SST_Thermal_4km_Day_Annual
MODIS_Aqua_L3_SST_Thermal_4km_Day_Daily
MODIS_Aqua_L3_SST_Thermal_4km_Night_8Day
MODIS_Aqua_L3_SST_Thermal_4km_Day_Monthly
MODIS_Aqua_L3_SST_Thermal_4km_Night_Daily
CERES_Combined_TOA_Longwave_Flux_All_Sky_Monthly
MODIS_Aqua_L3_SST_Thermal_4km_Night_Monthly
MODIS_Aqua_L3_SST_Thermal_9km_Day_8Day
MODIS_Aqua_L3_SST_Thermal_4km_Night_Annual
MODIS_Aqua_L3_SST_Thermal_9km_Day_Daily
MODIS_Aqua_L3_SST_Thermal_9km_Day_Annual
MODIS_Aqua_L3_SST_Thermal_9km_Night_8Day
MODIS_Aqua_L3_SST_Thermal_9km_Day_Monthly
MODIS_Aqua_L3_SST_Thermal_9km_Night_Daily
MODIS_Aqua_L3_SST_Thermal_9km_Night_Annual
MODIS_Aqua_Land_Surface_Temp_Day
MODIS_Aqua_L3_SST_Thermal_9km_Night_Monthly
MODIS_Aqua_Land_Surface_Temp_Night
MODIS_Aqua_SurfaceReflectance_Bands121
MODIS_Aqua_NDSI_Snow_Cover
MODIS_Aqua_Sea_Ice
MODIS_Aqua_SurfaceReflectance_Bands721
MODIS_Aqua_Water_Vapor_5km_Night
MODIS_Aqua_SurfaceReflectance_Bands143
MODIS_Aqua_Water_Vapor_5km_Day
MODIS_Terra_Aerosol
MODIS_Terra_Angstrom_Exponent_Land
MODIS_Combined_Value_Added_AOD
MODIS_Terra_Aerosol_Optical_Depth_3km
MODIS_Terra_Angstrom_Exponent_Ocean
MODIS_Terra_AOD_Deep_Blue_Combined
MODIS_Terra_AOD_Deep_Blue_Land
MODIS_Terra_Brightness_Temp_Band31_Day
MODIS_Terra_Brightness_Temp_Band31_Night
MODIS_Terra_Chlorophyll_A
MODIS_Terra_Cloud_Effective_Radius
MODIS_Terra_Cloud_Effective_Radius_37
MODIS_Terra_Cloud_Effective_Radius_PCL
MODIS_Terra_Cloud_Effective_Radius_37_PCL
MODIS_Terra_Cloud_Fraction_Night
MODIS_Terra_Cloud_Fraction_Day
MODIS_Terra_Cloud_Multi_Layer_Flag
MODIS_Terra_Cloud_Optical_Thickness
MODIS_Terra_Cloud_Optical_Thickness_PCL
MODIS_Terra_Cloud_Phase_Infrared_Day
MODIS_Terra_Cloud_Phase_Infrared_Night
MODIS_Terra_Cloud_Phase_Optical_Properties
MODIS_Terra_Cloud_Top_Height_Day
MODIS_Terra_Cloud_Top_Height_Night
MODIS_Terra_Cloud_Top_Pressure_Night
MODIS_Terra_Cloud_Top_Pressure_Day
MODIS_Terra_Cloud_Top_Temp_Day
MODIS_Terra_Cloud_Top_Temp_Night
MODIS_Terra_Cloud_Water_Path
MODIS_Terra_Cloud_Water_Path_PCL
MODIS_Terra_CorrectedReflectance_Bands367
MODIS_Terra_CorrectedReflectance_TrueColor
MODIS_Terra_CorrectedReflectance_Bands721
MODIS_Terra_Data_No_Data
MODIS_Terra_Ice_Surface_Temp_Day
MODIS_Terra_Ice_Surface_Temp_Night
MODIS_Terra_L3_SST_MidIR_4km_Night_8Day
MODIS_Terra_EVI_8Day
MODIS_Terra_L3_SST_MidIR_4km_Night_Annual
MODIS_Terra_L3_SST_MidIR_4km_Night_Daily
MODIS_Terra_L3_SST_MidIR_4km_Night_Monthly
MODIS_Terra_L3_SST_MidIR_9km_Night_8Day
MODIS_Terra_L3_SST_MidIR_9km_Night_Annual
MODIS_Terra_L3_SST_MidIR_9km_Night_Daily
MODIS_Terra_L3_SST_MidIR_9km_Night_Monthly
MODIS_Terra_L3_SST_Thermal_4km_Day_8Day
MODIS_Terra_L3_SST_Thermal_4km_Day_Annual
MODIS_Terra_L3_SST_Thermal_4km_Day_Daily
MODIS_Terra_L3_SST_Thermal_4km_Night_8Day
MODIS_Terra_L3_SST_Thermal_4km_Day_Monthly
MODIS_Terra_L3_SST_Thermal_4km_Night_Annual
MODIS_Terra_L3_SST_Thermal_4km_Night_Daily
MODIS_Terra_L3_SST_Thermal_4km_Night_Monthly
MODIS_Terra_L3_SST_Thermal_9km_Day_8Day
MODIS_Terra_L3_SST_Thermal_9km_Day_Annual
MODIS_Terra_L3_SST_Thermal_9km_Day_Daily
MODIS_Terra_L3_SST_Thermal_9km_Day_Monthly
MODIS_Terra_L3_SST_Thermal_9km_Night_8Day
MODIS_Terra_L3_SST_Thermal_9km_Night_Annual
MODIS_Terra_L3_SST_Thermal_9km_Night_Daily
MODIS_Terra_L3_SST_Thermal_9km_Night_Monthly
MODIS_Terra_Land_Surface_Temp_Day
MODIS_Terra_NDSI_Snow_Cover
MODIS_Terra_NDVI_8Day
MODIS_Terra_Sea_Ice
MODIS_Terra_Land_Surface_Temp_Night
MODIS_Terra_SurfaceReflectance_Bands143
MODIS_Terra_SurfaceReflectance_Bands121
MODIS_Terra_SurfaceReflectance_Bands721
MODIS_Terra_Water_Vapor_5km_Day
MODIS_Terra_Water_Vapor_5km_Night
MODIS_Water_Mask
MOPITT_CO_Daily_Surface_Mixing_Ratio_Day
MOPITT_CO_Daily_Surface_Mixing_Ratio_Night
MOPITT_CO_Daily_Total_Column_Day
MOPITT_CO_Daily_Total_Column_L2
MOPITT_CO_Daily_Total_Column_Night
MOPITT_CO_Monthly_Surface_Mixing_Ratio_Day
MOPITT_CO_Monthly_Surface_Mixing_Ratio_Night
MOPITT_CO_Monthly_Total_Column_Day
NDH_Drought_Hazard_Frequency_Distribution_1980-2000
NDH_Flood_Hazard_Frequency_Distribution_1985-2003
MOPITT_CO_Monthly_Total_Column_Night
NDH_Landslide_Hazard_Distribution_2000
NLDAS_Surface_Total_Precipitation_Primary_Monthly
NLDAS_Near_Surface_Air_Temperature_Primary_Monthly
NLDAS_Underground_Soil_Moisture_Mosaic_Monthly
NLDAS_Surface_Total_Precipitation_Secondary_Monthly
NLDAS_Underground_Soil_Moisture_Noah_Monthly
OLS_DMSP_F10_Digital_Derived_Lightning
OMI_Absorbing_Aerosol_Optical_Depth
NLDAS_Underground_Soil_Moisture_VIC_Monthly
OLS_DMSP_F12_Digital_Derived_Lightning
OMI_Absorbing_Aerosol_Optical_Thickness_MW_388
OMI_Aerosol_Optical_Depth
OMI_Aerosol_Index
OMI_Cloud_Pressure
OMI_Ozone_DOAS_Total_Column
OMI_Nitrogen_Dioxide_Tropo_Column
OMI_Ozone_TOMS_Total_Column
OMI_Single_Scattering_Albedo
OMI_SO2_Middle_Troposphere
OMI_SO2_Planetary_Boundary_Layer
OMI_SO2_Lower_Troposphere
OMI_SO2_Upper_Troposphere_and_Stratosphere
OMI_UV_Aerosol_Index
OMI_UV_Erythemal_Daily_Dose
OMI_UV_Erythemal_Dose_Rate
OMI_UV_Index
OMPS_Aerosol_Index
OMPS_Aerosol_Index_PyroCumuloNimbus
OMPS_Ozone_Total_Column
OMPS_SO2_Lower_Troposphere
OMPS_SO2_Middle_Troposphere
OMPS_SO2_Planetary_Boundary_Layer
OMPS_SO2_Upper_Troposphere_and_Stratosphere
OSCAR_Sea_Surface_Currents_Zonal
OSCAR_Sea_Surface_Currents_Meridional
OSM_Land_Mask
OSM_Land_Water_Map
OTD_High_Resolution_Full_Climatology_OTD_Flash_Rate_Climatology
OTD_High_Resolution_Full_Climatology_OTD_Scaled_Flashes
OTD_High_Resolution_Full_Climatology_OTD_Raw_Flashes
OTD_OrbView1_Flash_Radiance
Particulate_Matter_Below_2.5micrometers_2001-2010
Particulate_Matter_Below_2.5micrometers_2010-2012
Probabilities_of_Urban_Expansion_2000-2030
Reference_Features
RSS_Merged_Wind_Climatology_Monthly
RSS_Total_Precipitable_Water_Climatology_Monthly
Reference_Labels
SMAP_L1_Passive_Brightness_Temp_Aft_H_QA
SMAP_L1_Passive_Brightness_Temp_Aft_H
SMAP_L1_Passive_Brightness_Temp_Aft_V
SMAP_L1_Passive_Brightness_Temp_Aft_V_QA
SMAP_L1_Passive_Brightness_Temp_Aft_H_RFI
SMAP_L1_Passive_Brightness_Temp_Aft_V_RFI
SMAP_L1_Passive_Brightness_Temp_Fore_H
SMAP_L1_Passive_Brightness_Temp_Fore_H_QA
SMAP_L1_Passive_Brightness_Temp_Fore_H_RFI
SMAP_L1_Passive_Brightness_Temp_Fore_V_QA
SMAP_L1_Passive_Brightness_Temp_Fore_V
SMAP_L1_Passive_Brightness_Temp_Fore_V_RFI
SMAP_L1_Passive_Enhanced_Brightness_Temp_Aft_H
SMAP_L1_Passive_Enhanced_Brightness_Temp_Aft_H_QA
SMAP_L1_Passive_Enhanced_Brightness_Temp_Aft_H_RFI
SMAP_L1_Passive_Enhanced_Brightness_Temp_Aft_V
SMAP_L1_Passive_Enhanced_Brightness_Temp_Aft_V_QA
SMAP_L1_Passive_Enhanced_Brightness_Temp_Aft_V_RFI
SMAP_L1_Passive_Enhanced_Brightness_Temp_Fore_H
SMAP_L1_Passive_Enhanced_Brightness_Temp_Fore_H_QA
SMAP_L1_Passive_Enhanced_Brightness_Temp_Fore_H_RFI
SMAP_L1_Passive_Enhanced_Brightness_Temp_Fore_V
SMAP_L1_Passive_Enhanced_Brightness_Temp_Fore_V_QA
SMAP_L1_Passive_Faraday_Rotation_Aft
SMAP_L1_Passive_Enhanced_Brightness_Temp_Fore_V_RFI
SMAP_L1_Passive_Faraday_Rotation_Fore
SMAP_L2_Passive_Day_Soil_Moisture_Option1
SMAP_L2_Passive_Day_Soil_Moisture_Option2
SMAP_L2_Passive_Day_Soil_Moisture_Option3
SMAP_L2_Passive_Enhanced_Day_Soil_Moisture_Option1
SMAP_L2_Passive_Enhanced_Day_Soil_Moisture_Option2
SMAP_L2_Passive_Enhanced_Night_Soil_Moisture_Option1
SMAP_L2_Passive_Enhanced_Day_Soil_Moisture_Option3
SMAP_L2_Passive_Enhanced_Night_Soil_Moisture_Option2
SMAP_L2_Passive_Enhanced_Night_Soil_Moisture_Option3
SMAP_L2_Passive_Night_Soil_Moisture_Option1
SMAP_L2_Passive_Night_Soil_Moisture_Option2
SMAP_L3_Active_Passive_Brightness_Temp_H
SMAP_L2_Passive_Night_Soil_Moisture_Option3
SMAP_L3_Active_Passive_Brightness_Temp_V
SMAP_L3_Active_Passive_Soil_Moisture
SMAP_L3_Active_Sigma0_HH
SMAP_L3_Active_Sigma0_HH_QA
SMAP_L3_Active_Sigma0_HH_RFI
SMAP_L3_Active_Sigma0_VV
SMAP_L3_Active_Sigma0_VV_QA
SMAP_L3_Active_Sigma0_VV_RFI
SMAP_L3_Active_Sigma0_XPOL
SMAP_L3_Active_Sigma0_XPOL_QA
SMAP_L3_Active_Sigma0_XPOL_RFI
SMAP_L3_Passive_Brightness_Temp_H
SMAP_L3_Active_Soil_Moisture
SMAP_L3_Passive_Brightness_Temp_V
SMAP_L3_Passive_Day_Soil_Moisture
SMAP_L3_Passive_Day_Freeze_Thaw
SMAP_L3_Passive_Enhanced_Day_Soil_Moisture
SMAP_L3_Passive_Enhanced_Day_Freeze_Thaw
SMAP_L3_Passive_Enhanced_Night_Freeze_Thaw
SMAP_L3_Passive_Enhanced_Night_Soil_Moisture
SMAP_L3_Passive_Night_Freeze_Thaw
SMAP_L3_Passive_Night_Soil_Moisture
SMAP_L3_Sea_Surface_Salinity_CAP_Monthly
SMAP_L3_Sea_Surface_Salinity_CAP_8Day_RunningMean
SMAP_L3_Sea_Surface_Salinity_REMSS_8Day_RunningMean
SMAP_L3_Sea_Surface_Salinity_REMSS_Monthly
SMAP_L4_Analyzed_Surface_Soil_Moisture
SMAP_L4_Analyzed_Root_Zone_Soil_Moisture
SMAP_L4_Frozen_Area
SMAP_L4_Mean_Gross_Primary_Productivity
SMAP_L4_Mean_Heterotrophic_Respiration
SMAP_L4_Mean_Net_Ecosystem_Exchange
SMAP_L4_Emult_Average
SMAP_L4_Snow_Mass
SMAP_L4_Soil_Temperature_Layer_1
SMAP_L4_Uncertainty_Analyzed_Root_Zone_Soil_Moisture
SMAP_L4_Uncertainty_Analyzed_Surface_Soil_Moisture
SMAP_L4_Uncertainty_Mean_Net_Ecosystem_Exchange
SMAP_Sentinel-1_L2_Active_Passive_Soil_Moisture
SRTM_Color_Index
SSMI_DMSP_F10_Cloud_Liquid_Water_Over_Oceans_Ascending
SSMI_DMSP_F10_Cloud_Liquid_Water_Over_Oceans_Descending
SSMI_DMSP_F10_Rain_Rate_Over_Oceans_Ascending
SSMI_DMSP_F10_Rain_Rate_Over_Oceans_Descending
SSMI_DMSP_F10_Water_Vapor_Over_Oceans_Ascending
SSMI_DMSP_F10_Water_Vapor_Over_Oceans_Descending
SSMI_DMSP_F10_Wind_Speed_Over_Oceans_Ascending
SSMI_DMSP_F11_Cloud_Liquid_Water_Over_Oceans_Ascending
SSMI_DMSP_F10_Wind_Speed_Over_Oceans_Descending
SSMI_DMSP_F11_Cloud_Liquid_Water_Over_Oceans_Descending
SSMI_DMSP_F11_Rain_Rate_Over_Oceans_Ascending
SSMI_DMSP_F11_Rain_Rate_Over_Oceans_Descending
SSMI_DMSP_F11_Water_Vapor_Over_Oceans_Ascending
SSMI_DMSP_F11_Water_Vapor_Over_Oceans_Descending
SSMI_DMSP_F11_Wind_Speed_Over_Oceans_Ascending
SSMI_DMSP_F11_Wind_Speed_Over_Oceans_Descending
SSMI_DMSP_F13_Cloud_Liquid_Water_Over_Oceans_Ascending
SSMI_DMSP_F13_Cloud_Liquid_Water_Over_Oceans_Descending
SSMI_DMSP_F13_Rain_Rate_Over_Oceans_Ascending
SSMI_DMSP_F13_Rain_Rate_Over_Oceans_Descending
SSMI_DMSP_F13_Water_Vapor_Over_Oceans_Ascending
SSMI_DMSP_F13_Water_Vapor_Over_Oceans_Descending
SSMI_DMSP_F13_Wind_Speed_Over_Oceans_Ascending
SSMI_DMSP_F14_Cloud_Liquid_Water_Over_Oceans_Ascending
SSMI_DMSP_F13_Wind_Speed_Over_Oceans_Descending
SSMI_DMSP_F14_Rain_Rate_Over_Oceans_Ascending
SSMI_DMSP_F14_Cloud_Liquid_Water_Over_Oceans_Descending
SSMI_DMSP_F14_Rain_Rate_Over_Oceans_Descending
SSMI_DMSP_F14_Water_Vapor_Over_Oceans_Ascending
SSMI_DMSP_F14_Water_Vapor_Over_Oceans_Descending
SSMI_DMSP_F14_Wind_Speed_Over_Oceans_Ascending
SSMI_DMSP_F14_Wind_Speed_Over_Oceans_Descending
SSMI_DMSP_F15_Cloud_Liquid_Water_Over_Oceans_Ascending
SSMI_DMSP_F15_Cloud_Liquid_Water_Over_Oceans_Descending
SSMI_DMSP_F15_Rain_Rate_Over_Oceans_Descending
SSMI_DMSP_F15_Water_Vapor_Over_Oceans_Ascending
SSMI_DMSP_F15_Rain_Rate_Over_Oceans_Ascending
SSMI_DMSP_F15_Water_Vapor_Over_Oceans_Descending
SSMI_DMSP_F15_Wind_Speed_Over_Oceans_Ascending
SSMI_DMSP_F15_Wind_Speed_Over_Oceans_Descending
SSMI_DMSP_F16_Cloud_Liquid_Water_Over_Oceans_Descending
SSMI_DMSP_F16_Cloud_Liquid_Water_Over_Oceans_Ascending
SSMI_DMSP_F16_Rain_Rate_Over_Oceans_Ascending
SSMI_DMSP_F16_Rain_Rate_Over_Oceans_Descending
SSMI_DMSP_F16_Water_Vapor_Over_Oceans_Ascending
SSMI_DMSP_F16_Water_Vapor_Over_Oceans_Descending
SSMI_DMSP_F16_Wind_Speed_Over_Oceans_Ascending
SSMI_DMSP_F17_Cloud_Liquid_Water_Over_Oceans_Descending
SSMI_DMSP_F17_Rain_Rate_Over_Oceans_Ascending
SSMI_DMSP_F16_Wind_Speed_Over_Oceans_Descending
SSMI_DMSP_F17_Cloud_Liquid_Water_Over_Oceans_Ascending
SSMI_DMSP_F17_Rain_Rate_Over_Oceans_Descending
SSMI_DMSP_F17_Water_Vapor_Over_Oceans_Ascending
SSMI_DMSP_F17_Water_Vapor_Over_Oceans_Descending
SSMI_DMSP_F17_Wind_Speed_Over_Oceans_Ascending
SSMI_DMSP_F8_Cloud_Liquid_Water_Over_Oceans_Ascending
SSMI_DMSP_F17_Wind_Speed_Over_Oceans_Descending
SSMI_DMSP_F8_Rain_Rate_Over_Oceans_Ascending
SSMI_DMSP_F8_Cloud_Liquid_Water_Over_Oceans_Descending
SSMI_DMSP_F8_Rain_Rate_Over_Oceans_Descending
SSMI_DMSP_F8_Water_Vapor_Over_Oceans_Ascending
SSMI_DMSP_F8_Water_Vapor_Over_Oceans_Descending
SSMI_DMSP_F8_Wind_Speed_Over_Oceans_Ascending
SSMI_DMSP_F8_Wind_Speed_Over_Oceans_Descending
Summer_Day_Max_Land_Surface_Temp_2013
Summer_Night_Min_Land_Surface_Temp_2013
SWDB_Aerosol_Angstrom_Exponent_Daily
SWDB_Aerosol_Optical_Thickness_550nm_Daily
SWDB_Aerosol_Angstrom_Exponent_Monthly
SWDB_Aerosol_Optical_Thickness_550nm_Monthly
TOPEX-Poseidon_JASON_Sea_Surface_Currents_Meridional_US_West_Coast_GAFECC
TOPEX-Poseidon_JASON_Sea_Surface_Currents_Zonal_US_West_Coast_GAFECC
TOPEX-Poseidon_JASON_Sea_Surface_Height_Anomalies_GDR_Cycles
TOPEX-Poseidon_JASON_Sea_Surface_Height_Anomalies_Reconstructed
TOPEX-Poseidon_JASON_Sea_Surface_Height_Anomalies_US_West_Coast_GAFECC
UHI_Avg_Summer_Night_Min_Land_Surface_Temp_2013
UHI_Avg_Summer_Day_Max_Land_Surface_Temp_2013
UHI_Urban-Rural_Summer_Night_Min_Land_Surface_Temp_Difference_2013
UHI_Urban-Rural_Summer_Day_Max_Land_Surface_Temp_Difference_2013
VIIRS_Black_Marble
VIIRS_CityLights_2012
VIIRS_Night_Lights
VIIRS_SNPP_Brightness_Temp_BandI5_Day
VIIRS_SNPP_Brightness_Temp_BandI5_Night
VIIRS_SNPP_CorrectedReflectance_BandsM11-I2-I1
VIIRS_SNPP_CorrectedReflectance_BandsM3-I3-M11
VIIRS_SNPP_CorrectedReflectance_TrueColor
VIIRS_SNPP_DayNightBand_ENCC  
```
</p>
</details>


### Layers Metadata

The metadata for available GIBS layers is defined in the file `data.js` as `L.GIBS_LAYERS`. Keys are layer's IDs, values are the following objects:
  * `title` - layer's title
  * `template` - template of layer tiles
  * `zoom` - max zoom of the layer
  * `date` (boolean) - is the layer multi-temporal

### Available options 

The following options can be set:

|Option|Type|Description|
|---|---|---|
|`date`|`Date`|Date for multi-temporal products|
|`transparent`|`Boolean`|Make no-data pixels of MODIS Multiband Imagery transparent|

## Data 

The layer data source used is [this xml](https://gibs.earthdata.nasa.gov/wmts/epsg3857/best/1.0.0/WMTSCapabilities.xml) - _last update done on 4/02/2019_

## Tests

You can test which layers are functioning/broken running 

```
npm test
```
